multiFixKind property
The fix kind that should be used to build a multi-fix, or null if this
producer doesn't support multi-fixes.
Implementation
@override
FixKind? get multiFixKind => _multiKind;
The fix kind that should be used to build a multi-fix, or null if this
producer doesn't support multi-fixes.
@override
FixKind? get multiFixKind => _multiKind;